==> cck_select_other-8.x-1.0-rc1.tar.gz: cck_select_other/src/Tests/CCKSelectOtherTestBase.php <==
<?php
/**
 * @file
 * CCKSelectOtherTestBase.php
 */

namespace Drupal\cck_select_other\Tests;

use Drupal\simpletest\WebTestBase;

/**
 * CCK Select Other Test Base.
 */
abstract class CCKSelectOtherTestBase extends WebTestBase {

  public static $modules = array('node', 'field_ui', 'options', 'cck_select_other');

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->contentType = $this->drupalCreateContentType();
    $this->admin_user = $this->drupalCreateUser(array('administer content types', 'administer site configuration'));
    $this->web_user = $this->drupalCreateUser(array('access content', 'create ' . $this->contentType->id() . ' content', 'delete any ' . $this->contentType->id() . ' content', 'bypass node access'));
  }

  /**
   * Create a list field. This is not done via the interface beacuse what's
   * good enough for Drupal Core is good enough for Drupal Contrib.
   *
   * @param $type
   *   The field type. Defaults to text field.
   * @param $field_info
   *   Field definition info to merge into defaults.
   * @param $instance_info
   *   Field instance definition to merge into defaults.
   * @return string
   *   The field name.
   */
  public function createSelectOtherListField($type = 'list_string', $field_info = array(), $instance_info = array()) {
    $field_storage = $field_info + array(
      'field_name' => strtolower($this->randomMachineName()),
      'entity_type' => 'node',
      'type' => $type,
    );

    // Create a test field and instance.
    $field = entity_create('field_storage_config', $field_storage);
    $this->assertTrue($field->save(), 'Successfully saved field storage configuration.');

    // Create field instance.
    $field_definition = $instance_info + array(
      'field_name' => $field->getName(),
      'entity_type' => 'node',
      'bundle' => $this->contentType->id(),
      'label' => $this->randomString(15),
    );

    $this->assertTrue(entity_create('field_config', $field_definition)->save(), 'Successfully saved field configuration.');

    // Set the form display.
    entity_get_form_display('node', $this->contentType->id(), 'default')
      ->setComponent($field->getName(), array(
        'type' => 'cck_select_other',
      ))
      ->save();

    // Set the formatter.
    entity_get_display('node', $this->contentType->id(), 'default')
      ->setComponent($field->getName(), array(
        'type' => 'cck_select_other',
      ))
      ->save();

    return $field;
  }

  /**
   * Get a random option in a list of options.
   *
   * @param $options
   *   An array of list options
   * @return array
   *   An indexed array of the key and value.
   */
  public function getRandomOption($options) {
    $option = array_rand($options);
    return array($option, $options[$option]);
  }

  /**
   * Create select list options
   *
   * @param $num
   *   The number of options to create.
   * @return array
   *   An associative array of allowed values keyed by value and the
   *   label as the array item value.
   */
  public function createOptions($num = 5) {
    $options = '';
    for ($i = 0; $i < $num; $i++) {
      $label = $this->getRandomGenerator()->word(10);
      $key = strtolower($label);
      $options[$key] = $label;
    }
    return $options;
  }

  /**
   * Convert select list options into allowed values string copied from Core.
   *
   * @param $values
   *   An associative array of values.
   *
   * @see Drupal\options\Plugin\Field\FieldType\FieldItemBase::allowedValuesString().
   *
   * It is terrible that this method is protected and not static. DrupalWTF.
   */
  public function allowedValuesString(array $values) {
    $lines = array();
    foreach ($values as $key => $value) {
      $lines[] = "$key|$value";
    }
    return implode("\n", $lines);
  }
}

==> cck_select_other-8.x-1.1.tar.gz: cck_select_other/src/Tests/CCKSelectOtherTestBase.php <==
<?php

namespace Drupal\cck_select_other\Tests;

use Drupal\simpletest\WebTestBase;

/**
 * CCK Select Other Test Base.
 */
abstract class CCKSelectOtherTestBase extends WebTestBase {

  public static $modules = array('node', 'field_ui', 'options', 'cck_select_other');

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->contentType = $this->drupalCreateContentType();
    $this->admin_user = $this->drupalCreateUser(array('administer content types', 'administer site configuration'));
    $this->web_user = $this->drupalCreateUser(array('access content', 'create ' . $this->contentType->id() . ' content', 'delete any ' . $this->contentType->id() . ' content', 'bypass node access'));
  }

  /**
   * Create a list field. This is not done via the interface beacuse what's
   * good enough for Drupal Core is good enough for Drupal Contrib.
   *
   * @param $type
   *   The field type. Defaults to text field.
   * @param $field_info
   *   Field definition info to merge into defaults.
   * @param $instance_info
   *   Field instance definition to merge into defaults.
   * @return string
   *   The field name.
   */
  public function createSelectOtherListField($type = 'list_string', $field_info = array(), $instance_info = array()) {
    $field_storage = $field_info + array(
      'field_name' => strtolower($this->randomMachineName()),
      'entity_type' => 'node',
      'type' => $type,
    );

    // Create a test field and instance.
    $field = entity_create('field_storage_config', $field_storage);
    $this->assertTrue($field->save(), 'Successfully saved field storage configuration.');

    // Create field instance.
    $field_definition = $instance_info + array(
      'field_name' => $field->getName(),
      'entity_type' => 'node',
      'bundle' => $this->contentType->id(),
      'label' => $this->randomString(15),
    );

    $this->assertTrue(entity_create('field_config', $field_definition)->save(), 'Successfully saved field configuration.');

    // Set the form display.
    entity_get_form_display('node', $this->contentType->id(), 'default')
      ->setComponent($field->getName(), array(
        'type' => 'cck_select_other',
      ))
      ->save();

    // Set the formatter.
    entity_get_display('node', $this->contentType->id(), 'default')
      ->setComponent($field->getName(), array(
        'type' => 'cck_select_other',
      ))
      ->save();

    return $field;
  }

  /**
   * Get a random option in a list of options.
   *
   * @param $options
   *   An array of list options
   * @return array
   *   An indexed array of the key and value.
   */
  public function getRandomOption($options) {
    $option = array_rand($options);
    return array($option, $options[$option]);
  }

  /**
   * Create select list options
   *
   * @param $num
   *   The number of options to create.
   * @return array
   *   An associative array of allowed values keyed by value and the
   *   label as the array item value.
   */
  public function createOptions($num = 5) {
    $options = '';
    for ($i = 0; $i < $num; $i++) {
      $label = $this->getRandomGenerator()->word(10);
      $key = strtolower($label);
      $options[$key] = $label;
    }
    return $options;
  }

  /**
   * Convert select list options into allowed values string copied from Core.
   *
   * @param $values
   *   An associative array of values.
   *
   * @see \Drupal\options\Plugin\Field\FieldType\FieldItemBase::allowedValuesString().
   *
   * It is terrible that this method is protected and not static. DrupalWTF.
   */
  public function allowedValuesString(array $values) {
    $lines = array();
    foreach ($values as $key => $value) {
      $lines[] = "$key|$value";
    }
    return implode("\n", $lines);
  }
}
